HistoryEntry class

Entry in navigation history

Annotations

Constructors

HistoryEntry({required String path, required DateTime timestamp, required NavigationType type, Duration? timeOnRoute})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
path String
The path that was navigated to
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeOnRoute Duration?
Time spent on this route (set when route is left)
final
timestamp DateTime
When this navigation occurred
final
type NavigationType
Type of navigation action
final

Methods

copyWith({String? path, DateTime? timestamp, NavigationType? type, Duration? timeOnRoute}) HistoryEntry
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited